rad.labels <- 
function(ref=NULL, data=FALSE, labels=TRUE, ...) {
         
  Read(ref, data=FALSE, labels=TRUE, ...)

}
